==> lazydl-0.0.1.tar.gz: lazydl-0.0.1/lazydl/utils/init.py <==
from omegaconf import DictConfig, OmegaConf
import os
import json
from lazydl.utils.log import Logger
from typing import Union
import comet_ml
import sys
import hashlib

log = Logger(__name__) 


def init_env(config: Union[DictConfig, dict]) -> None:
    """初始化环境，包括随机种子、可见GPU、Comet.ml环境变量、进程名

    Args:
        config (DictConfig, dict): 配置文件
            seed (str, optional): 种子. Defaults to '3407'.
            use_deterministic (bool, optional): 是否使用确定性算法，使用了训练会变慢. Defaults to False.
            visibale_cuda (str, optional): 设置可见 GPU，如果不使用设置为 ''. Defaults to 'all'.
            proctitle (str, optional): 进程名. Defaults to 'python'.
            proctitle_prefix_id (bool, optional): 是否在进程名前边添加进程 ID. Defaults to True.
    """
    if isinstance(config, dict):
        config = OmegaConf.create(config)
    OmegaConf.set_struct(config, False)
    updated_env = {}
    
    # ---------------------------------------------------------------------------- #
    #                         生成 Task ID                                     
    # ---------------------------------------------------------------------------- #
    config.task_id = "{}@{}".format(config.get("task_id", "No task identifier."), os.getpid())
    
    
    # ---------------------------------------------------------------------------- #
    #                         设置可见 GPU                                                          
    # ---------------------------------------------------------------------------- #
    if config.get("env.visibale_cuda", "all") != "all":
        os.environ['CUDA_VISIBLE_DEVICES'] = config.get("visibale_cuda")
        updated_env['CUDA_VISIBLE_DEVICES'] = os.environ['CUDA_VISIBLE_DEVICES']
    
    # ---------------------------------------------------------------------------- #
    #                         设置随机种子                                           
    # ---------------------------------------------------------------------------- #
    seed = config.get("seed", 3407)
    use_deterministic = config.get("use_deterministic", False)
    import random
    import numpy as np
    import torch
    random.seed(seed)   # Python的随机性
    os.environ['PYTHONHASHSEED'] = str(seed)    # 设置Python哈希种子，为了禁止hash随机化，使得实验可复现
    updated_env['PYTHONHASHSEED'] = os.environ['PYTHONHASHSEED']
    np.random.seed(seed)   # numpy的随机性
    torch.manual_seed(seed)   # torch的CPU随机性，为CPU设置随机种子
    torch.cuda.manual_seed(seed)   # torch的GPU随机性，为当前GPU设置随机种子
    torch.cuda.manual_seed_all(seed)  # if you are using multi-GPU.   torch的GPU随机性，为所有GPU设置随机种子
    torch.backends.cudnn.benchmark = not use_deterministic # if benchmark=True, deterministic will be False
    torch.backends.cudnn.deterministic = use_deterministic   # 选择确定性算法
    
    # # ---------------------------------------------------------------------------- #
    # #                         设置 Comet.ml 环境变量                                     
    # # ---------------------------------------------------------------------------- #
    os.environ["COMET_API_KEY"] = config.get("comet_api_key", "")
    
    updated_env['COMET_API_KEY'] = os.environ['COMET_API_KEY']
    
    # ---------------------------------------------------------------------------- #
    #                         设置 Comet Project                                     
    # ---------------------------------------------------------------------------- #
    api = comet_ml.api.API()
    experiment = api.get_experiment_by_key(config.get("task_id", "No task identifier."))
    
    if experiment is None:
        experiment = comet_ml.Experiment(project_name=config.get("comet_project", "No comet project."),
                                         experiment_key=config.get("task_id", "No task identifier."),)
        experiment.set_name(config.get("comet_name", "Null name"))
        
        experiment_config = sys.argv[-1].replace("+experiments=", "")

    
    tmux_session = "/"
    for arg in sys.argv:
        if "tmux_session" in arg:
            tmux_session = arg.replace("+tmux_session=", "")
            
    experiment.log_other("tmux_session", tmux_session)
    experiment.log_other("进程ID", str(os.getpid()))
    experiment.log_other("实验配置文件", experiment_config)
    for key, value in config.items():
        if isinstance(value, dict):
            value = json.dumps(value)
        experiment.log_other(key, str(value))
    for tag in config.get("comet_tags", []):
        experiment.add_tag(tag)
    
    config.comet = experiment
    
    # ---------------------------------------------------------------------------- #
    #                         设置钉钉 Token                                     
    # ---------------------------------------------------------------------------- #
    os.environ["DINGDING_ACCESS_TOKEN"] = config.get("dingding_access_token", "")
    os.environ["DINGDING_SECRET"] = config.get("dingding_secret", "")
    
    updated_env['DINGDING_ACCESS_TOKEN'] = os.environ['DINGDING_ACCESS_TOKEN']
    updated_env['DINGDING_SECRET'] = os.environ['DINGDING_SECRET']
    
        
    # ---------------------------------------------------------------------------- #
    #                         设置其他环境变量                                     
    # ---------------------------------------------------------------------------- #
    os.environ["TOKENIZERS_PARALLELISM"] = config.get("tokenizers_parallelism", "False")
    updated_env['TOKENIZERS_PARALLELISM'] = os.environ['TOKENIZERS_PARALLELISM']
    
    
    # ---------------------------------------------------------------------------- #
    #                         设置进程名                                     
    # ---------------------------------------------------------------------------- #
    import setproctitle
    if config.get("proctitle_prefix_id", True):
        setproctitle.setproctitle(str(os.getpid()) + "| " + config.get("proctitle", "python"))
    else:
        setproctitle.setproctitle(config.get("proctitle", "python"))
        
    # ---------------------------------------------------------------------------- #
    #                        打印环境变量                                      
    # ---------------------------------------------------------------------------- #
    log.info(json.dumps(updated_env, indent=4, ensure_ascii=False).replace("{", "Environment Variables\n").replace("}", ""))
    
    # ---------------------------------------------------------------------------- #
    #                         设置处理器类型                                     
    # ---------------------------------------------------------------------------- #
    processing_unit = config.get("processing_unit", "cpu")
    if processing_unit == "cpu":
        config.processing_unit_type = "cpu"
    elif processing_unit == "mps":
        config.processing_unit_type = "mps"
    else:
        if not torch.cuda.is_available():
            log.error("CUDA is not available, please check your CUDA installation.")
            raise Exception("CUDA is not available, please check your CUDA installation.")
        if "^" in processing_unit:
            # 自动选择 GPU
            processing_unit = int(processing_unit.replace("^", ""))
            if processing_unit >= torch.cuda.device_count():
                log.error("The number of GPUs you specified is greater than the number of GPUs available.")
                raise Exception("The number of GPUs you specified is greater than the number of GPUs available.")
            if processing_unit > 1:
                config.processing_unit_type = "gpu-a-m"
            else:
                config.processing_unit_type = "gpu-a-s"
        else:
            processing_unit = processing_unit.split(",")
            if len(processing_unit) > torch.cuda.device_count():
                log.error("The number of GPUs you specified is greater than the number of GPUs available.")
                raise Exception("The number of GPUs you specified is greater than the number of GPUs available.")
            if len(processing_unit) > 1:
                config.processing_unit_type = "gpu-m-m"
            else:
                config.processing_unit_type = "gpu-m-s"
        config.processing_unit = processing_unit
        
    log.info(f"Processing unit type: {config.get('processing_unit_type')}")
    log.info(f"Processing unit: {config.get('processing_unit')}")
    
    return config

==> lazydl-0.0.2.tar.gz: lazydl-0.0.2/lazydl/utils/init.py <==
from omegaconf import DictConfig, OmegaConf
import os
import json
from lazydl.utils.log import Logger
from typing import Union
import comet_ml
import sys
import datetime

log = Logger(__name__) 


def init_env(config: Union[DictConfig, dict]) -> None:
    """初始化环境，包括随机种子、可见GPU、Comet.ml环境变量、进程名

    Args:
        config (DictConfig, dict): 配置文件
            seed (str, optional): 种子. Defaults to '3407'.
            use_deterministic (bool, optional): 是否使用确定性算法，使用了训练会变慢. Defaults to False.
            visibale_cuda (str, optional): 设置可见 GPU，如果不使用设置为 ''. Defaults to 'all'.
            proctitle (str, optional): 进程名. Defaults to 'python'.
            proctitle_prefix_id (bool, optional): 是否在进程名前边添加进程 ID. Defaults to True.
    """
    if isinstance(config, dict):
        config = OmegaConf.create(config)
    OmegaConf.set_struct(config, False)
    updated_env = {}
    
    # ---------------------------------------------------------------------------- #
    #                         生成 Task ID                                     
    # ---------------------------------------------------------------------------- #
    config.task_id = "{}@{}".format(config.get("task_id", datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S")), os.getpid())
    
    
    # ---------------------------------------------------------------------------- #
    #                         设置可见 GPU                                                          
    # ---------------------------------------------------------------------------- #
    if config.get("env.visibale_cuda", "all") != "all":
        os.environ['CUDA_VISIBLE_DEVICES'] = config.get("visibale_cuda")
        updated_env['CUDA_VISIBLE_DEVICES'] = os.environ['CUDA_VISIBLE_DEVICES']
    
    # ---------------------------------------------------------------------------- #
    #                         设置随机种子                                           
    # ---------------------------------------------------------------------------- #
    seed = config.get("seed", 3407)
    use_deterministic = config.get("use_deterministic", False)
    import random
    import numpy as np
    import torch
    random.seed(seed)   # Python的随机性
    os.environ['PYTHONHASHSEED'] = str(seed)    # 设置Python哈希种子，为了禁止hash随机化，使得实验可复现
    updated_env['PYTHONHASHSEED'] = os.environ['PYTHONHASHSEED']
    np.random.seed(seed)   # numpy的随机性
    torch.manual_seed(seed)   # torch的CPU随机性，为CPU设置随机种子
    torch.cuda.manual_seed(seed)   # torch的GPU随机性，为当前GPU设置随机种子
    torch.cuda.manual_seed_all(seed)  # if you are using multi-GPU.   torch的GPU随机性，为所有GPU设置随机种子
    torch.backends.cudnn.benchmark = not use_deterministic # if benchmark=True, deterministic will be False
    torch.backends.cudnn.deterministic = use_deterministic   # 选择确定性算法
    
    # ---------------------------------------------------------------------------- #
    #                         设置 Comet.ml 环境变量                                     
    # ---------------------------------------------------------------------------- #
    os.environ["COMET_API_KEY"] = "" if config.get("comet_api_key") is None else config.get("comet_api_key")
    
    updated_env['COMET_API_KEY'] = os.environ['COMET_API_KEY']
    
    # ---------------------------------------------------------------------------- #
    #                         设置 Comet Project                                     
    # ---------------------------------------------------------------------------- #
    api = comet_ml.api.API()
    experiment = api.get_experiment_by_key(config.get("task_id", "No task identifier."))
    
    if experiment is None:
        experiment = comet_ml.Experiment(project_name=config.get("comet_project", "No comet project."),
                                         experiment_key=config.get("task_id", "No task identifier."),)
        experiment.set_name(config.get("comet_name", "Null name"))
        
        experiment_config = sys.argv[-1].replace("+experiments=", "")

    
    tmux_session = "/"
    for arg in sys.argv:
        if "tmux_session" in arg:
            tmux_session = arg.replace("+tmux_session=", "")
            
    experiment.log_other("tmux_session", tmux_session)
    experiment.log_other("进程ID", str(os.getpid()))
    experiment.log_other("实验配置文件", experiment_config)
    for key, value in config.items():
        if isinstance(value, dict):
            value = json.dumps(value)
        experiment.log_other(key, str(value))
    for tag in config.get("comet_tags", []):
        experiment.add_tag(tag)
    
    config.comet = experiment
    
    # ---------------------------------------------------------------------------- #
    #                         设置钉钉 Token                                     
    # ---------------------------------------------------------------------------- #
    os.environ["DINGDING_ACCESS_TOKEN"] = config.get("dingding_access_token", "")
    os.environ["DINGDING_SECRET"] = config.get("dingding_secret", "")
    
    updated_env['DINGDING_ACCESS_TOKEN'] = os.environ['DINGDING_ACCESS_TOKEN']
    updated_env['DINGDING_SECRET'] = os.environ['DINGDING_SECRET']
    
        
    # ---------------------------------------------------------------------------- #
    #                         设置其他环境变量                                     
    # ---------------------------------------------------------------------------- #
    os.environ["TOKENIZERS_PARALLELISM"] = config.get("tokenizers_parallelism", "False")
    updated_env['TOKENIZERS_PARALLELISM'] = os.environ['TOKENIZERS_PARALLELISM']
    
    
    # ---------------------------------------------------------------------------- #
    #                         设置进程名                                     
    # ---------------------------------------------------------------------------- #
    import setproctitle
    if config.get("proctitle_prefix_id", True):
        setproctitle.setproctitle(str(os.getpid()) + "| " + config.get("proctitle", "python"))
    else:
        setproctitle.setproctitle(config.get("proctitle", "python"))
        
    # ---------------------------------------------------------------------------- #
    #                        打印环境变量                                      
    # ---------------------------------------------------------------------------- #
    log.info(json.dumps(updated_env, indent=4, ensure_ascii=False).replace("{", "Environment Variables\n").replace("}", ""))
    
    # ---------------------------------------------------------------------------- #
    #                         设置处理器类型                                     
    # ---------------------------------------------------------------------------- #
    processing_unit = config.get("processing_unit", "cpu")
    if processing_unit == "cpu":
        config.processing_unit_type = "cpu"
    elif processing_unit == "mps":
        config.processing_unit_type = "mps"
    else:
        if not torch.cuda.is_available():
            log.error("CUDA is not available, please check your CUDA installation.")
            raise Exception("CUDA is not available, please check your CUDA installation.")
        if "^" in processing_unit:
            # 自动选择 GPU
            processing_unit = int(processing_unit.replace("^", ""))
            if processing_unit >= torch.cuda.device_count():
                log.error("The number of GPUs you specified is greater than the number of GPUs available.")
                raise Exception("The number of GPUs you specified is greater than the number of GPUs available.")
            if processing_unit > 1:
                config.processing_unit_type = "gpu-a-m"
            else:
                config.processing_unit_type = "gpu-a-s"
        else:
            processing_unit = processing_unit.split(",")
            if len(processing_unit) > torch.cuda.device_count():
                log.error("The number of GPUs you specified is greater than the number of GPUs available.")
                raise Exception("The number of GPUs you specified is greater than the number of GPUs available.")
            if len(processing_unit) > 1:
                config.processing_unit_type = "gpu-m-m"
            else:
                config.processing_unit_type = "gpu-m-s"
        config.processing_unit = processing_unit
        
    log.info(f"Processing unit type: {config.get('processing_unit_type')}")
    log.info(f"Processing unit: {config.get('processing_unit')}")
    
    return config
